@@ -2,7 +2,7 @@
 package mac
 
 import (
-	"errors"
+	"fmt"
 	"os/exec"
 	"strings"
 
@@ -20,6 +20,7 @@ func CodeName(osVersion string) string {
 
 	// https://en.wikipedia.org/wiki/List_of_Apple_codenames
 	major := map[int]string{
+		15: "sequoia",
 		14: "sonoma",
 		13: "ventura",
 		12: "monterey",
@@ -57,8 +58,7 @@ func CodeName(osVersion string) string {
 func Version() (string, error) {
 	o, err := exec.Command("sw_vers", "-productVersion").Output()
 	if err != nil {
-		return "", errors.Join(errors.New("could not run sw_vers -productVersion"), err)
+		return "", fmt.Errorf("could not run sw_vers -productVersion: %w", err)
 	}
-
 	return strings.TrimRight(string(o), "\n"), nil
 }
